@@ -28,7 +28,7 @@ wngqd1=wing_quadrant(sld, sect1=sect1, sect2=sect2)
 wngqd2=wing_quadrant(sld, sect1=sect2, sect2=sect3, control_names=['aileron'], control_axpercs_x=[[0.75, 0.75]], control_axpercs_thickness=[[0.5, 0.5]])
 wng=wing(sld, wingquads=[wngqd1, wngqd2])
 acft=aircraft(sld, elems=[wng])
-acft.edit_parameters({'Uinf':0.01, 'aileron':1})
+acft.edit_parameters({'Uinf':0.01, 'aileron':20.0})
 wng.patchcompose(ydisc=70)
 sld.plotgeometry(xlim=[-c/2, c*3/4], ylim=[-c/2, c/2], zlim=[-c/2, c/2])
 acft.addwake()
