@@ -180,4 +180,7 @@ def PG_inv_xmult(beta, a, b): #inverse of the matrix before
     return lg.inv(PG_xmult(beta, a, b))
 
 def PG_vtouni(beta, a, b): #returns matrix converting incompressible PG calculated velocities to compressible case
-    return Mstreamtouni(a, b)@np.diag(np.array([1.0, beta, beta]))@Mtostream(a, b)
\ No newline at end of file
+    return Mstreamtouni(a, b)@np.diag(np.array([1.0, beta, beta]))@Mtostream(a, b)
+
+def PG_unitov(beta, a, b): #inverse of function in prior entry
+    return lg.inv(PG_vtouni(beta, a, b))
\ No newline at end of file
